import React, { Component, Fragment } from "react";
import { withTheme, withStyles } from "@material-ui/core/styles";
import {
  Grid,
  Paper,
  Select,
  FormControl,
  InputLabel,
  MenuItem,
  Typography,
  Divider,
  TextField,
  FormControlLabel,
  Checkbox,
  Avatar
} from "@material-ui/core";
import { DatePicker } from "@material-ui/pickers";
import { Form } from "@openimis/fe-core";

const styles = theme => ({
  paper: theme.paper.paper,
  paperHeader: theme.paper.header,
  paperHeaderAction: theme.paper.action,
  item: theme.paper.item,
  tableTitle: theme.table.title,
  label: {
    color: theme.palette.primary.main
  },
  photo: {
    height: "100%"
  }
});

const rels = [
  { value: "1", label: "Brother/Sister" },
  { value: "2", label: "Father/Mother" },
  { value: "3", label: "Uncle/Aunt" },
  { value: "4", label: "Son/Daughter" },
  { value: "5", label: "Spouse" },
  { value: "6", label: "Other" }
];

const regions = [
  { value: "r1", label: "R1 Ultha" },
  { value: "r2", label: "R2 Tahida" }
];

const districts = [
  { value: "r1d1", label: "R1D1 Rapta" },
  { value: "r1d2", label: "R1D2 Jambero" },
  { value: "r1d3", label: "R1D3 Uptol" }
];

const municipalities = [
  { value: "r1d1m1", label: "R1D1M1 Achi" },
  { value: "r1d1m2", label: "R1D1M2 Jamu" },
  { value: "r1d1m3", label: "R1D1M3 Adhi" },
  { value: "r1d1m4", label: "R1D1M4 Jobber" },
  { value: "r1d1m5", label: "R1D1M5 Radler" }
];

const villages = [
  { value: "r1d1m1v1", label: "R1D1M1V1 Rachla" },
  { value: "r1d1m1v2", label: "R1D1M1v2 Darbu" },
  { value: "r1d1m1v3", label: "R1D1M1V3 Agdo" },
  { value: "r1d1m1v4", label: "R1D1M1V4 Nonteng North" }
];

const genders = [
  { value: "m", label: "Male" },
  { value: "f", label: "Female" },
  { value: "o", label: "Other" }
];

const maritals = [
  { value: "s", label: "Single" },
  { value: "m", label: "Married" },
  { value: "d", label: "Divorced" },
  { value: "w", label: "Widdowed" },
  { value: "o", label: "Not Specified" }
];

const profs = [
  { value: "e", label: "Employee" },
  { value: "s", label: "Self Employee" },
  { value: "h", label: "Housewife" },
  { value: "o", label: "Other" }
];

const educs = [
  { value: "p", label: "Primary school" },
  { value: "s", label: "Secondary school" },
  { value: "g", label: "Post graduate" },
  { value: "u", label: "University" },
  { value: "o", label: "Other" }
];

const ids = [
  { value: "n", label: "National ID" },
  { value: "d", label: "Driver license" },
  { value: "p", label: "Passport" },
  { value: "v", label: "Visa" }
];

const levels = [
  { value: "d", label: "Dispensary" },
  { value: "c", label: "Health Center" },
  { value: "h", label: "Hospital" }
];

const hfs = [{ value: "1", label: "Rapta District Hospital" }];

const confirms = [{ value: "1", label: "Municipality" }];

class RDLocation extends Component {
  render() {
    const { classes, ro = false, x = 1 } = this.props;

    return (
      <Fragment>
        <Grid item xs={3 * x} className={classes.item}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Region</InputLabel>
            <Select value="r1" readOnly={ro}>
              {regions.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>District</InputLabel>
            <Select value="r1d1" readOnly={ro}>
              {districts.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
      </Fragment>
    );
  }
}

const StyledRDLocation = withTheme(withStyles(styles)(RDLocation));

class MVLocation extends Component {
  render() {
    const { classes, ro = false, x = 1 } = this.props;

    return (
      <Fragment>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Municipality</InputLabel>
            <Select value="r1d1m1" readOnly={ro}>
              {municipalities.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Village</InputLabel>
            <Select value="r1d1m1v1" readOnly={ro}>
              {villages.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
      </Fragment>
    );
  }
}

const StyledMVLocation = withTheme(withStyles(styles)(MVLocation));

class FamilyMasterPanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Fragment>
        <Typography className={classes.tableTitle}>
          Family/Group Details
        </Typography>
        <Divider />
        <Grid container spacing={3} className={classes.item}>
          <StyledRDLocation ro={true} />
          <StyledMVLocation ro={true} />
          <Grid item xs={3}>
            <TextField
              fullWidth
              disabled={true}
              required={true}
              label="Insurance Number"
              InputLabelProps={{
                className: classes.label
              }}
              value="0109830929"
            />
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              disabled={true}
              label="Last Name"
              required={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="Brook"
            />
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              disabled={true}
              label="Given Name"
              required={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="James"
            />
          </Grid>
          <Grid item xs={3}>
            <FormControlLabel
              control={
                <Checkbox disabled={true} color="primary" checked={true} />
              }
              label="Povrety Status"
            />
          </Grid>
          <Grid item xs={3}>
            <FormControl required={true} fullWidth>
              <InputLabel className={classes.label}>
                Confirmation Type
              </InputLabel>
              <Select value="1" readOnly={true}>
                {confirms.map((option, idx) => (
                  <MenuItem value={option.value}>{option.label}</MenuItem>
                ))}
              </Select>
            </FormControl>
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              disabled={true}
              label="Confirmation Number"
              required={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="HAKDK-636872"
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              fullWidth
              multiline
              rows={2}
              disabled={true}
              label="Permanent Address Details"
              required={true}
              InputLabelProps={{
                className: classes.label
              }}
              value={`Street n° 267\n638702 Location`}
            />
          </Grid>
        </Grid>
      </Fragment>
    );
  }
}

const StyledFamilyMasterPanel = withTheme(
  withStyles(styles)(FamilyMasterPanel)
);

class InsureePanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Paper className={classes.paper}>
        <Grid container className={classes.item}>
          <Grid item xs={2}>
            <Typography className={classes.tableTitle}>
              Insuree Details
            </Typography>
          </Grid>
          <Grid item xs={10}>
            <FormControl required={true} fullWidth>
              <InputLabel className={classes.label}>Relationship</InputLabel>
              <Select value="4">
                {rels.map((option, idx) => (
                  <MenuItem key={`region-${idx}`} value={option.value}>
                    {option.label}
                  </MenuItem>
                ))}
              </Select>
            </FormControl>
          </Grid>
        </Grid>
        <Divider />
        <Grid container spacing={3}>
          <Grid item xs={12}>
            <Grid container spacing={3} className={classes.item}>
              <Grid item xs={4}>
                <TextField
                  fullWidth
                  required={true}
                  label="Insurance Number"
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
              <Grid item xs={4}>
                <TextField
                  fullWidth
                  label="Last Name"
                  required={true}
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
              <Grid item xs={4}>
                <TextField
                  fullWidth
                  label="Given Name"
                  required={true}
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
            </Grid>
          </Grid>
          <Grid item xs={6}>
            <Grid container spacing={3} className={classes.item}>
              <Grid item xs={3}>
                <DatePicker
                  fullWidth
                  format="YYYY-MM-DD"
                  required={true}
                  clearable
                  InputLabelProps={{
                    className: classes.label
                  }}
                  label="Date of Birth"
                />
              </Grid>
              <Grid item xs={3}>
                <FormControl required={true} fullWidth>
                  <InputLabel className={classes.label}>Gender</InputLabel>
                  <Select required={true}>
                    {genders.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={3}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>
                    Marital Status
                  </InputLabel>
                  <Select>
                    {maritals.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={3}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>
                    Beneficiary Card
                  </InputLabel>
                  <Select>
                    {["yes", "no"].map((option, idx) => (
                      <MenuItem value={option}>{option}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <StyledRDLocation x={2} />
              <StyledMVLocation x={2} />
              <Grid item xs={12}>
                <TextField
                  fullWidth
                  multiline
                  rows={2}
                  label="Address Details"
                  required={true}
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
              <Grid item xs={6}>
                <TextField
                  fullWidth
                  label="Phone"
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
              <Grid item xs={6}>
                <TextField
                  fullWidth
                  label="Email"
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
              <Grid item xs={6}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>Profession</InputLabel>
                  <Select>
                    {profs.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={6}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>Education</InputLabel>
                  <Select>
                    {educs.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={6}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>
                    Identification Type
                  </InputLabel>
                  <Select>
                    {ids.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={6}>
                <TextField
                  fullWidth
                  label="Identification Number"
                  InputLabelProps={{
                    className: classes.label
                  }}
                />
              </Grid>
            </Grid>
          </Grid>
          <Grid item xs={6}>
            <Grid
              container
              justify="center"
              alignItems="center"
              className={classes.photo}
            >
              <Grid item>
                <Avatar alt="" src="" />
              </Grid>
            </Grid>
          </Grid>
          <Grid item xs={12}>
            <Divider />
          </Grid>
          <Grid item xs={12}>
            <Grid container spacing={3} className={classes.item}>
              <Grid item xs={12}>
                <Typography className={classes.tableTitle}>
                  First Service Point
                </Typography>
              </Grid>
              <StyledRDLocation r="Region of FSP" d="District of FSP" />
              <Grid item xs={3}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>
                    Level of FSP
                  </InputLabel>
                  <Select value="h">
                    {levels.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
              <Grid item xs={3}>
                <FormControl fullWidth>
                  <InputLabel className={classes.label}>
                    Health Facility
                  </InputLabel>
                  <Select value="1">
                    {hfs.map((option, idx) => (
                      <MenuItem value={option.value}>{option.label}</MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </Paper>
    );
  }
}

const StyledInsureePanel = withTheme(withStyles(styles)(InsureePanel));

class InsureeForm extends Component {
  render() {
    return (
      <div>
        <Form
          HeadPanel={StyledFamilyMasterPanel}
          back={e => {}}
          title="Insuree"
          Panels={[StyledInsureePanel]}
        />
      </div>
    );
  }
}

export default withTheme(withStyles(styles)(InsureeForm));
